pub struct ALPSlots {
pub encoded: ArrayRef,
pub patch_indices: Option<ArrayRef>,
pub patch_values: Option<ArrayRef>,
pub patch_chunk_offsets: Option<ArrayRef>,
}Fields
encoded: ArrayRefThe ALP-encoded values array.
patch_indices: Option<ArrayRef>The indices of exception values that could not be ALP-encoded.
patch_values: Option<ArrayRef>The exception values that could not be ALP-encoded.
patch_chunk_offsets: Option<ArrayRef>Chunk offsets for the patch indices/values.
Implementations
Sourceimpl ALPSlots
impl ALPSlots
Sourcepub const PATCH_INDICES: usize = 1usize
pub const PATCH_INDICES: usize = 1usize
Slot index for patch_indices.
Sourcepub const PATCH_VALUES: usize = 2usize
pub const PATCH_VALUES: usize = 2usize
Slot index for patch_values.
Sourcepub const PATCH_CHUNK_OFFSETS: usize = 3usize
pub const PATCH_CHUNK_OFFSETS: usize = 3usize
Slot index for patch_chunk_offsets.
Sourcepub fn from_slots(slots: Vec<Option<ArrayRef>>) -> Self
pub fn from_slots(slots: Vec<Option<ArrayRef>>) -> Self
Convert owned slot storage into an owned slot struct.
Sourcepub fn into_slots(self) -> Vec<Option<ArrayRef>>
pub fn into_slots(self) -> Vec<Option<ArrayRef>>
Convert this slot struct into storage order.