pub struct ALPRDArray(/* private fields */);Implementations
Sourceimpl ALPRDArray
impl ALPRDArray
Sourceimpl ALPRDArray
impl ALPRDArray
pub fn try_new( dtype: DType, left_parts: ArrayData, left_parts_dict: impl AsRef<[u16]>, right_parts: ArrayData, right_bit_width: u8, left_parts_patches: Option<Patches>, ) -> VortexResult<Self>
Sourcepub fn is_f32(&self) -> bool
pub fn is_f32(&self) -> bool
Returns true if logical type of the array values is f32.
Returns false if the logical type of the array values is f64.
Sourcepub fn left_parts(&self) -> ArrayData
pub fn left_parts(&self) -> ArrayData
The leftmost (most significant) bits of the floating point values stored in the array.
These are bit-packed and dictionary encoded, and cannot directly be interpreted without the metadata of this array.
Sourcepub fn right_parts(&self) -> ArrayData
pub fn right_parts(&self) -> ArrayData
The rightmost (least significant) bits of the floating point values stored in the array.
Sourcepub fn left_parts_patches(&self) -> Option<Patches>
pub fn left_parts_patches(&self) -> Option<Patches>
Patches of left-most bits.
Sourcepub fn left_parts_dict(&self) -> &[u16]
pub fn left_parts_dict(&self) -> &[u16]
The dictionary that maps the codes in left_parts into bit patterns.